@@ -387,7 +387,9 @@ class HTTP_WebDAV_Server_LetoDMS extends HTTP_WebDAV_Server
 		$format = "%15s  %-19s  %-s\n";
 
 		$subfolders = $folder->getSubFolders();
+		$subfolders = LetoDMS_Core_DMS::filterAccess($subfolders, $this->user, M_READ);
 		$documents = $folder->getDocuments();
+		$documents = LetoDMS_Core_DMS::filterAccess($documents, $this->user, M_READ);
 		$objs = array_merge($subfolders, $documents);
 
 		echo "<html><head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" /><title>Index of ".htmlspecialchars($options['path'])."</title></head>\n";
@@ -489,13 +491,19 @@ class HTTP_WebDAV_Server_LetoDMS extends HTTP_WebDAV_Server
 				else $fileType = substr($name, $lastDotIndex);
 		}
 		if($document = $this->dms->getDocumentByName($name, $folder)) {
-			if(!$document->addContent('', $this->user, $tmpFile, $name, $fileType, $mimetype, array(), array(), 0)) {
+			if ($document->getAccessMode($this->user) < M_READWRITE) {
+				unlink($tmpFile);
+				return "403 Forbidden";
+			} elseif(!$document->addContent('', $this->user, $tmpFile, $name, $fileType, $mimetype, array(), array(), 0)) {
 				unlink($tmpFile);
 				return "409 Conflict";
 			}
 
 		} else {
-			if(!$res = $folder->addDocument($name, '', 0, $this->user, '', array(), $tmpFile, $name, $fileType, $mimetype, 0, array(), array(), 0, "")) {
+			if ($folder->getAccessMode($this->user) < M_READWRITE) {
+				unlink($tmpFile);
+				return "403 Forbidden";
+			} elseif(!$res = $folder->addDocument($name, '', 0, $this->user, '', array(), $tmpFile, $name, $fileType, $mimetype, 0, array(), array(), 0, "")) {
 				unlink($tmpFile);
 				return "409 Conflict";
 			}
@@ -549,6 +557,10 @@ class HTTP_WebDAV_Server_LetoDMS extends HTTP_WebDAV_Server
 			return "403 Forbidden";				 
 		}
 
+		if ($folder->getAccessMode($this->user) < M_READWRITE) {
+			return "403 Forbidden";				 
+		}
+
 		if (!$folder->addSubFolder($name, '', $this->user, 0)) {
 			return "403 Forbidden";				 
 		}
@@ -805,6 +817,10 @@ class HTTP_WebDAV_Server_LetoDMS extends HTTP_WebDAV_Server
 				return false;
 		}
 
+		if ($obj->getAccessMode($this->user) < M_READWRITE) {
+			return false;				 
+		}
+
 		foreach ($options["props"] as $key => $prop) {
 			if ($prop["ns"] == "DAV:") {
 				$options["props"][$key]['status'] = "403 Forbidden";
